@@ -10,9 +10,7 @@
 
 	// Language and character set
 	$lang['applang'] = 'Deutsch';
-	$lang['appcharset'] = 'UTF-8';
-	$lang['applocale'] = 'de_DE';
-	$lang['appdbencoding'] = 'LATIN1';
+	$lang['applocale'] = 'de-DE';
 	$lang['applangdir'] = 'ltr';
 
 	// Welcome
@@ -23,7 +21,7 @@
 	$lang['strlocaldocs'] = 'PostgreSQL Dokumentation (lokal)';
 	$lang['strreportbug'] = 'Fehler melden';
 	$lang['strviewfaq'] = 'Online-FAQ ansehen';
-	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
+	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
 	
 	// Basic strings
 	$lang['strlogin'] = 'Anmelden';
@@ -139,6 +137,7 @@
 	$lang['strselectall'] = 'Alle auswählen';
 	$lang['strunselectall'] = 'Alle abwählen';
 	$lang['strlocale'] = 'Spracheinstellung';
+	$lang['strcluster'] = 'Cluster';
 
 	// User-supplied SQL history
 	$lang['strhistory'] = 'Befehlsspeicher';
@@ -171,7 +170,6 @@
 	$lang['strnodata'] = 'Keine Datensätze gefunden.';
 	$lang['strnoobjects'] = 'Keine Objekte gefunden.';
 	$lang['strrownotunique'] = 'Dieser Datensatz hat keine eindeutige Spalte.';
-	$lang['strnoreportsdb'] = 'Sie haben die Berichtsdatenbank nicht angelegt. In der Datei INSTALL finden Sie Anweisungen dafür.';
 	$lang['strnouploads'] = 'Das Hochladen von Dateien ist ausgeschaltet.';
 	$lang['strimporterror'] = 'Importfehler.';
 	$lang['strimporterror-fileformat'] = 'Importfehler: Dateiformat konnte nicht automatisch bestimmt werden.';
@@ -626,18 +624,6 @@
 	$lang['strspecifyschematodrop'] = 'Sie müssen mindestens ein Schema angeben, das gelöscht werden soll.';
 
 	// Reports
-	$lang['strreport'] = 'Bericht';
-	$lang['strreports'] = 'Berichte';
-	$lang['strshowallreports'] = 'Alle Berichte anzeigen';
-	$lang['strnoreports'] = 'Keine Berichte gefunden.';
-	$lang['strcreatereport'] = 'Bericht erstellen.';
-	$lang['strreportdropped'] = 'Bericht gelöscht.';
-	$lang['strreportdroppedbad'] = 'Löschen des Berichtes fehlgeschlagen.';
-	$lang['strconfdropreport'] = 'Sind Sie sicher, dass Sie den Bericht "%s" löschen wollen?';
-	$lang['strreportneedsname'] = 'Sie müssen für den Bericht einen Namen angeben.';
-	$lang['strreportneedsdef'] = 'Sie müssen eine SQL-Abfrage für den Bericht eingeben.';
-	$lang['strreportcreated'] = 'Bericht gespeichert.';
-	$lang['strreportcreatedbad'] = 'Speichern des Berichtes fehlgeschlagen.';
 
 	// Domains
 	$lang['strdomain'] = 'Domäne';
@@ -770,120 +756,8 @@
 	$lang['strtablespacealtered'] = 'Tablespace geändert.';
 	$lang['strtablespacealteredbad'] = 'Ändern des Tablespace fehlgeschlagen.';
 
-	// Slony clusters
-	$lang['strcluster'] = 'Cluster';
-	$lang['strnoclusters'] = 'Keine Cluster gefunden.';
-	$lang['strconfdropcluster'] = 'Sind Sie sicher, dass Sie den Cluster "%s" löschen möchten?';
-	$lang['strclusterdropped'] = 'Cluster gelöscht.';
-	$lang['strclusterdroppedbad'] = 'Löschen des Clusters fehlgeschlagen.';
-	$lang['strinitcluster'] = 'Cluster initialisieren';
-	$lang['strclustercreated'] = 'Cluster initialisiert.';
-	$lang['strclustercreatedbad'] = 'Initialisierung des Clusters fehlgeschlagen.';
-	$lang['strclusterneedsname'] = 'Sie müssen einen Namen für den Cluster angeben.';
-	$lang['strclusterneedsnodeid'] = 'Sie müssen eine ID für den lokalen Cluster-Knoten angeben.';
-
-	// Slony nodes
-	$lang['strnodes'] = 'Cluster-Knoten';
-	$lang['strnonodes'] = 'Keine Cluster-Knoten gefunden.';
-	$lang['strcreatenode'] = 'Cluster-Knoten erstellen';
-	$lang['strid'] = 'ID';
-	$lang['stractive'] = 'Aktiv';
-	$lang['strnodecreated'] = 'Cluster-Knoten erstellt.';
-	$lang['strnodecreatedbad'] = 'Erstellen des Cluster-Knotens fehlgeschlagen.';
-	$lang['strconfdropnode'] = 'Sind Sie sicher, dass Sie Cluster-Knoten "%s" löschen möchten?';
-	$lang['strnodedropped'] = 'Cluster-Knoten gelöscht.';
-	$lang['strnodedroppedbad'] = 'Löschen des Cluster-Knotens fehlgeschlagen.';
-	$lang['strfailover'] = 'Übernahme';
-	$lang['strnodefailedover'] = 'Cluster-Knoten übernommen.';
-	$lang['strnodefailedoverbad'] = 'Übernahme des Cluster-Knotens fehlgeschlagen.';
-	$lang['strstatus'] = 'Status';	
-	$lang['strhealthy'] = 'Gesund';
-	$lang['stroutofsync'] = 'Nicht Synchronisiert';
-	$lang['strunknown'] = 'Unbekannt';	
-
-	// Slony paths	
-	$lang['strpaths'] = 'Kommunikationspfade';
-	$lang['strnopaths'] = 'Keine Kommunikationspfade gefunden.';
-	$lang['strcreatepath'] = 'Kommunikationspfad erstellen';
-	$lang['strnodename'] = 'Name des Cluster-Knotens';
-	$lang['strnodeid'] = 'ID des Cluster-Knotens';
-	$lang['strconninfo'] = 'Connection-String';
-	$lang['strconnretry'] = 'Wartezeit vor erneutem Verbindungsversuch in Sekunden';
-	$lang['strpathneedsconninfo'] = 'Sie müssen einen Connection-String für den Kommunikationspfad angeben.';
-	$lang['strpathneedsconnretry'] = 'Sie müssen die Wartezeit vor einem erneuten Verbindungsversuch angeben.';
-	$lang['strpathcreated'] = 'Kommunikationspfad erstellt.';
-	$lang['strpathcreatedbad'] = 'Erstellen des Kommunikationspfades fehlgeschlagen.';
-	$lang['strconfdroppath'] = 'Sind Sie sicher, dass Sie den Kommunikationspfad "%s" löschen möchten?';
-	$lang['strpathdropped'] = 'Kommunikationspfad gelöscht.';
-	$lang['strpathdroppedbad'] = 'Löschen des Kommunikationspfades fehlgeschlagen.';
-
-	// Slony listens
-	$lang['strlistens'] = 'Zuhörer';
-	$lang['strnolistens'] = 'Keine Zuhörer gefunden.';
-	$lang['strcreatelisten'] = 'Zuhörer erstellen';
-	$lang['strlistencreated'] = 'Zuhörer erstellt.';
-	$lang['strlistencreatedbad'] = 'Erstellen des Zuhörers fehlgeschlagen.';
-	$lang['strconfdroplisten'] = 'Sind Sie sicher, dass Sie Zuhörer "%s" löschen möchten?';
-	$lang['strlistendropped'] = 'Zuhörer gelöscht.';
-	$lang['strlistendroppedbad'] = 'Löschen des Zuhörers fehlgeschlagen.';
-
-	// Slony replication sets
-	$lang['strrepsets'] = 'Replikationsgruppe';
-	$lang['strnorepsets'] = 'Keine Replikationsgruppen gefunden.';
-	$lang['strcreaterepset'] = 'Replikationsgruppe erstellen';
-	$lang['strrepsetcreated'] = 'Replikationsgruppe erstellt.';
-	$lang['strrepsetcreatedbad'] = 'Erstellen der Replikationsgruppe fehlgeschlagen.';
-	$lang['strconfdroprepset'] = 'Sind Sie sicher, dass Sie Replikationsgruppe "%s" löschen möchten?';
-	$lang['strrepsetdropped'] = 'Replikationsgruppe gelöscht.';
-	$lang['strrepsetdroppedbad'] = 'Löschen der Replikationsgruppe fehlgeschlagen.';
-	$lang['strmerge'] = 'Vereinigen';
-	$lang['strmergeinto'] = 'Vereinigen mit';
-	$lang['strrepsetmerged'] = 'Replikationsgruppen vereinige.';
-	$lang['strrepsetmergedbad'] = 'Vereinigung der Replikationsgruppen fehlgeschlagen.';
-	$lang['strmove'] = 'Verschieben';
-	$lang['strneworigin'] = 'Neuer Usrprung';
-	$lang['strrepsetmoved'] = 'Replikationsgruppe verschoben.';
-	$lang['strrepsetmovedbad'] = 'Verschieben der Replikationsgruppe fehlgeschlagen.';
-	$lang['strnewrepset'] = 'Neue Replikationsgruppe';
-	$lang['strlock'] = 'Sperren';
-	$lang['strlocked'] = 'Gesperrt';
-	$lang['strunlock'] = 'Entsperren';
-	$lang['strconflockrepset'] = 'Sind Sie sicher, dass Sie Replikationsgruppe "%s" sperren möchten?';
-	$lang['strrepsetlocked'] = 'Replikationsgruppe gesperrt.';
-	$lang['strrepsetlockedbad'] = 'Sperren der Replikationsgruppe fehlgeschlagen.';
-	$lang['strconfunlockrepset'] = 'Sind Sie sicher, dass Sie Replikationsgruppe "%s" entsperren möchten?';
-	$lang['strrepsetunlocked'] = 'Replikationsgruppe entsperrt.';
-	$lang['strrepsetunlockedbad'] = 'Entsperren der Replikationsgruppe fehlgeschlagen.';
-	$lang['stronlyonnode'] = 'Nur auf dem Cluster-Knoten';
-	$lang['strddlscript'] = 'DDL-Script';
-	$lang['strscriptneedsbody'] = 'Sie müssen ein Script angeben, das auf allen Cluster-Knoten ausgeführt werden soll.';
-	$lang['strscriptexecuted'] = 'DDL-Script für die Replikationsgruppe ausgeführt.';
-	$lang['strscriptexecutedbad'] = 'Ausführung des DDL-Scripts für die Replikationsgruppe fehlgeschlagen.';
-	$lang['strtabletriggerstoretain'] = 'Die folgenden Trigger werden von Slony NICHT deaktiviert:';
-
-	// Slony tables in replication sets
-	$lang['straddtable'] = 'Tabelle hinzufügen';
-	$lang['strtableneedsuniquekey'] = 'Damit eine Tabelle hinzugefügt werden kann, muss sie einen Primärschlüssel oder einen eindeutigen Schlüssel besitzen.';
-	$lang['strtableaddedtorepset'] = 'Tabelle zu Replikationsgruppe hinzugefügt.';
-	$lang['strtableaddedtorepsetbad'] = 'Hinzufügen der Tabelle zur Replikationsgruppe fehlgeschlagen.';
-	$lang['strconfremovetablefromrepset'] = 'Sind Sie sicher, dass Sie die Tabelle "%s" aus der Replikationsgruppe "%s" entfernen möchten?';
-	$lang['strtableremovedfromrepset'] = 'Tabelle aus Replikationsgruppe entfernt.';
-	$lang['strtableremovedfromrepsetbad'] = 'Entfernen der Tabelle aus der Replikationsgruppe fehlgeschlagen.';
-
-	// Slony sequences in replication sets
-	$lang['straddsequence'] = 'Sequenz hinzufügen';
-	$lang['strsequenceaddedtorepset'] = 'Sequenz zu Replikationsgruppe hinzugefügt.';
-	$lang['strsequenceaddedtorepsetbad'] = 'Hinzufügen der Sequenz zur Replikationsgruppe fehlgeschlagen.';
-	$lang['strconfremovesequencefromrepset'] = 'Sind Sie sicher, dass Sie die Sequenz "%s" aus der Replikationsgruppe "%s" entfernen möchten?';
-	$lang['strsequenceremovedfromrepset'] = 'Sequenz aus Replikationsgruppe entfernt.';
-	$lang['strsequenceremovedfromrepsetbad'] = 'Entfernen der Sequenz aus der Replikationsgruppe fehlgeschlagen.';
-
-	// Slony subscriptions
-	$lang['strsubscriptions'] = 'Abonnements';
-	$lang['strnosubscriptions'] = 'Keine Abonnements gefunden.';
-
 	// Miscellaneous
-	$lang['strtopbar'] = '%s läuft auf %s:%s -- Sie sind als "%s" angemeldet, %s';
+	$lang['strtopbar'] = '%s läuft auf %s:%s -- Sie sind als "%s" angemeldet';
 	$lang['strtimefmt'] = 'D, j. n. Y, G:i';
 	$lang['strhelp'] = 'Hilfe';
 	$lang['strhelpicon'] = '?';
@@ -891,7 +765,7 @@
 	$lang['strselecthelppage'] = 'Hilfeseite auswählen';
 	$lang['strinvalidhelppage'] = 'Ungültige Hilfeseite.';
 	$lang['strlogintitle'] = 'Bei %s anmelden';
-	$lang['strlogoutmsg'] = 'Von %s abgemendet';
+	$lang['strlogoutmsg'] = 'Von %s abgemeldet';
 	$lang['strloading'] = 'Lade...';
 	$lang['strerrorloading'] = 'Fehler beim Laden';
 	$lang['strclicktoreload'] = 'Klicken Sie zum Neuladen';
